<?php

/**
 * @file
 * Settings page callback file for the visitors module.
 */

/**
 * Create visitors settings form.
 *
 * @return array
 *   The form.
 */
function visitors_admin_settings() {
  $roles = [];
  foreach (user_roles() as $role) {
    $roles[$role] = $role;
  }
  $form = array();

  // Statistics settings.
  $form['visitors_statistics'] = array(
    '#type' => 'fieldset',
    '#title' => t('Visitors statistics'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#description' => t('Visitors statistics settings'),
  );

  $form['visitors_statistics']['visitors_exclude_user1'] = array(
    '#type' => 'checkbox',
    '#title' => t('Exclude user1 from statistics'),
    '#default_value' => variable_get('visitors_exclude_user1', 0),
    '#description' => t('Exclude hits of user1 from statistics.'),
  );
  $form['visitors_statistics']['visitors_excluded_roles'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Excluded Roles'),
    '#options' => $roles,
    '#default_value' => variable_get('visitors_excluded_roles', []),
  );

  $form['visitors_statistics']['visitors_lines_per_page'] = array(
    '#type' => 'select',
    '#title' => 'Lines per page',
    '#default_value' => variable_get('visitors_lines_per_page', 10),
    '#options' => array(
      5 => 5,
      10 => 10,
      25 => 25,
      50 => 50,
      100 => 100,
      200 => 200,
      250 => 250,
      500 => 500,
      1000 => 1000,
    ),
    '#description' => t('The default maximum number of lines to display per page.'),
  );

  $period = drupal_map_assoc(
    array(
      3600,
      10800,
      21600,
      32400,
      43200,
      86400,
      172800,
      259200,
      604800,
      1209600,
      2419200,
      4838400,
      9676800,
      31536000,
    ),
      'format_interval'
    );
  $period[0] = t('Never');

  $form['visitors_statistics']['visitors_flush_log_timer'] = array(
    '#type' => 'select',
    '#title' => t('Discard visitors logs older than'),
    '#default_value'   => variable_get('visitors_flush_log_timer', 0),
    '#options' => $period,
    '#description' =>
    t('Older visitors log entries (including referrer statistics) will be automatically discarded. (Requires a correctly configured <a href="@cron">cron maintenance task</a>.)',
        array('@cron' => url('admin/reports/status'))
    ),
  );

  // Chart settings.
  $form['visitors_chart_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Chart settings'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
    '#description' => t('Visitors chart settings'),
  );

  $form['visitors_chart_settings']['visitors_chart_width'] = array(
    '#type' => 'textfield',
    '#title' => t('Width'),
    '#default_value' => variable_get('visitors_chart_width', 700),
    '#description' => t('Chart width.'),
  );

  $form['visitors_chart_settings']['visitors_chart_height'] = array(
    '#type' => 'textfield',
    '#title' => t('Height'),
    '#default_value' => variable_get('visitors_chart_height', 430),
    '#description' => t('Chart height.'),
  );

  $installed = array_filter(list_themes(), function ($obj) {
    return $obj->status;
  });

  $themes = array('_admin' => t('admin'), '_default' => t('default')) + array_map(function ($value) {
    return $value->name;
  }, $installed);

  $form['visitors_theme'] = array(
    '#title' => t('Theme'),
    '#description' => t('Select a theme for the Visitors reports.'),
    '#type' => 'select',
    '#options' => $themes,
    '#default_value' => variable_get('visitors_theme', '_admin'),
  );

  return system_settings_form($form);
}
